@@ -7,7 +7,7 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::{
-    chunk_store::{BlobChunkStore, UsedSpace},
+    chunk_store::BlobChunkStore,
     error::convert_to_error_message,
     node_ops::{NodeDuties, NodeDuty, OutgoingMsg},
     Error, Result,
@@ -33,8 +33,9 @@ pub(crate) struct ChunkStorage {
 }
 
 impl ChunkStorage {
-    pub(crate) async fn new(path: &Path, used_space: UsedSpace) -> Result<Self> {
-        let chunks = BlobChunkStore::new(path, used_space).await?;
+    #[allow(dead_code)]
+    pub(crate) async fn new(path: &Path, max_capacity: u64) -> Result<Self> {
+        let chunks = BlobChunkStore::new(path, max_capacity).await?;
         Ok(Self { chunks })
     }
 
@@ -219,7 +220,6 @@ impl Display for ChunkStorage {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::chunk_store::UsedSpace;
     use crate::error::Error::InvalidOwners;
     use crate::error::Result;
     use bls::SecretKey;
@@ -238,7 +238,7 @@ mod tests {
     #[tokio::test]
     pub async fn try_store_stores_public_blob() -> Result<()> {
         let path = PathBuf::from(temp_dir()?.path());
-        let mut storage = ChunkStorage::new(&path, UsedSpace::new(u64::MAX)).await?;
+        let mut storage = ChunkStorage::new(&path, u64::MAX).await?;
         let value = "immutable data value".to_owned().into_bytes();
         let blob = Blob::Public(PublicBlob::new(value));
         assert!(storage
@@ -253,7 +253,7 @@ mod tests {
     #[tokio::test]
     pub async fn try_store_stores_private_blob() -> Result<()> {
         let path = PathBuf::from(temp_dir()?.path());
-        let mut storage = ChunkStorage::new(&path, UsedSpace::new(u64::MAX)).await?;
+        let mut storage = ChunkStorage::new(&path, u64::MAX).await?;
         let value = "immutable data value".to_owned().into_bytes();
         let key = get_random_pk();
         let blob = Blob::Private(PrivateBlob::new(value, key));
@@ -269,7 +269,7 @@ mod tests {
     #[tokio::test]
     pub async fn try_store_errors_if_end_user_doesnt_own_data() -> Result<()> {
         let path = PathBuf::from(temp_dir()?.path());
-        let mut storage = ChunkStorage::new(&path, UsedSpace::new(u64::MAX)).await?;
+        let mut storage = ChunkStorage::new(&path, u64::MAX).await?;
         let value = "immutable data value".to_owned().into_bytes();
         let data_owner = get_random_pk();
         let end_user = get_random_pk();
