@@ -11,7 +11,6 @@ mod reading;
 mod writing;
 
 use crate::{
-    chunk_store::UsedSpace,
     node_ops::{NodeDuties, NodeDuty},
     Result,
 };
@@ -37,9 +36,9 @@ pub(crate) struct Chunks {
 }
 
 impl Chunks {
-    pub async fn new(path: &Path, used_space: UsedSpace) -> Result<Self> {
+    pub async fn new(path: &Path, max_capacity: u64) -> Result<Self> {
         Ok(Self {
-            chunk_storage: ChunkStorage::new(path, used_space).await?,
+            chunk_storage: ChunkStorage::new(path, max_capacity).await?,
         })
     }
 
